@@ -20,6 +20,8 @@ from fabric import colors
 from fabric.api import env, settings
 from fabric.utils import abort
 
+from littlechef.settings import cookbook_paths
+
 
 def get_nodes():
     """Gets all nodes found in the nodes/ directory"""
@@ -31,9 +33,8 @@ def get_nodes():
                                     and not f.startswith('.')]):
         hostname = ".".join(filename.split('.')[:-1])#remove .json from name
         node = get_node(hostname)
-        # Don't append "nodename" to the root namespace
-        # because it could colide with some cookbook's attribute
-        node['littlechef'] = {'nodename': hostname}
+        # Add node name so that we can tell to which node the data belongs to
+        node['name'] = hostname
         nodes.append(node)
     return nodes
 
@@ -41,7 +42,7 @@ def get_nodes():
 def get_node(name):
     node_path = os.path.join("nodes", name + ".json")
     if not os.path.exists(node_path):
-        abort("No config file found for node '{0}'".format(name))
+        return {'run_list': []}
     # Read node.json
     with open(node_path, 'r') as f:
         try:
@@ -55,7 +56,7 @@ def get_node(name):
 
 def print_node(node, detailed=False):
     """Pretty prints the given node"""
-    nodename = node['littlechef']['nodename']
+    nodename = node['name']
     print(colors.yellow("\n" + nodename))
     # Roles
     if detailed:
@@ -78,7 +79,7 @@ def print_node(node, detailed=False):
         print "    {0}: {1}".format(attribute, node[attribute])
 
 
-def get_recipes_in_cookbook(name, cookbook_paths):
+def get_recipes_in_cookbook(name):
     """Gets the name of all recipes present in a cookbook"""
     recipes = []
     path = None
@@ -140,13 +141,13 @@ def get_recipes_in_node(node):
     return recipes
 
 
-def get_recipes(cookbook_paths):
+def get_recipes():
     """Gets all recipes found in the cookbooks/ directory"""
     recipes = []
     for dirname in sorted(
         [d for d in os.listdir('cookbooks') if os.path.isdir(
             os.path.join('cookbooks', d)) and not d.startswith('.')]):
-        recipes.extend(get_recipes_in_cookbook(dirname, cookbook_paths))
+        recipes.extend(get_recipes_in_cookbook(dirname))
     return recipes
 
 
@@ -214,7 +215,7 @@ def print_role(role, detailed=True):
     print("")
 
 
-def get_cookbook_path(cookbook_name, cookbook_paths):
+def get_cookbook_path(cookbook_name):
     """Returns path to the cookbook for the given cookbook name"""
     for cookbook_path in cookbook_paths:
         path = os.path.join(cookbook_path, cookbook_name)
